@@ -1,16 +1,15 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.026-2-g34c7767
+package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.030-2-gd4c04cb
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Specify dynamic (user-side) prerequisites for your distribution
 # KEYWORDS: plugin distribution metadata MYMETA prerequisites Makefile.PL dynamic
 
-our $VERSION = '0.027'; # TRIAL
+our $VERSION = '0.031'; # TRIAL
 
 use Moose;
 with
     'Dist::Zilla::Role::FileGatherer',
-    'Dist::Zilla::Role::ModuleIncluder',
     'Dist::Zilla::Role::ModuleMetadata',
     'Dist::Zilla::Role::FileMunger',
     'Dist::Zilla::Role::MetaProvider',
@@ -234,18 +233,18 @@ sub _build__sub_definitions
 
 my %sub_prereqs = (
     can_cc => {
-        'Config' => '0',
+        'Config' => '0',                # core since perl 5.00307
     },
     can_run => {
-        'File::Spec' => '0',
-        'Config' => '0',
+        'File::Spec' => '0',            # core since perl 5.00405
+        'Config' => '0',                # core since perl 5.00307
     },
     parse_args => {
-        'Text::ParseWords' => '0',
+        'Text::ParseWords' => '0',      # core since perl 5.000
     },
     has_module => {
-        'Module::Metadata' => '0',
-        'CPAN::Meta::Requirements' => '2.120620',   # for add_string_requirement
+        'Module::Metadata' => '0',      # core since perl 5.013009
+        'CPAN::Meta::Requirements' => '2.120620',   # core since perl 5.015007
     },
 );
 
@@ -269,18 +268,23 @@ sub gather_files {
         {
             (my $path = $module) =~ s{::}{/}g;
             $path = path('inc', $path . '.pm');
+            my $cpath = $path->canonpath;
 
-            my $file = (first { $_->name eq $path } @{ $self->zilla->files })
-                # TODO this requires a new release of ModuleIncluder
-                # || ($self->include_modules([ $module ], '5.006001'))[0];
-                || do {
-                    $self->log([ 'inlining %s into inc/', $module ]);
-                    $self->include_modules([ $module ], version->new('5.006001'));
-                    first { $_->name eq $path } @{ $self->zilla->files };
-                };
+            my $file = first { $_->name eq $path or $_->name eq $cpath } @{ $self->zilla->files };
+            if (not $file) {
+                $self->log([ 'inlining %s into inc/', $module ]);
+                my $installed_filename = Module::Metadata->find_module_by_name($module)
+                    or $self->log_fatal([ 'Can\'t locate %s', $module ]);
+
+                $file = Dist::Zilla::File::OnDisk->new({ name => $installed_filename });
+                $file->name($path->stringify);
+                $self->add_file($file);
+            }
+            $self->log_fatal([ 'failed to find %s in files', $module ]) if not $file;
 
             if (defined $include_modules->{$module} and $include_modules->{$module} > 0)
             {
+                # check that the file we got actually satisfies our dependency
                 my $mmd = $self->module_metadata_for_file($file);
                 $self->log_fatal([ '%s version %s required--only found version %s',
                         $module, $include_modules->{$module},
@@ -401,7 +405,7 @@ Dist::Zilla::Plugin::DynamicPrereqs - Specify dynamic (user-side) prerequisites
 
 =head1 VERSION
 
-version 0.027
+version 0.031
 
 =head1 SYNOPSIS
 
@@ -562,7 +566,7 @@ C<parse_args()> - returns the hashref of options that were passed as arguments t
 
 =item *
 
-C<can_xs()> - XS capability testing via L<ExtUtils::HasCompiler> (don't forget to also check C<want_pp>!)
+C<can_xs()> - XS capability testing via L<ExtUtils::HasCompiler> (don't forget to also check C<want_pp>!) Available in this form since 0.029.
 
 =item *
 
@@ -576,9 +580,11 @@ C<can_run()> - check if we can run some command
 
 C<can_use($module [, $version ])> - checks if a module (optionally, at a specified version) can be loaded. (If you don't want to load the module, you should use C<< has_module >>, see below.)
 
+=for stopwords backcompat
+
 =item *
 
-C<has_module($module [, $version_or_range ])> - checks if a module (optionally, at a specified version or matching a L<version range|CPAN::Meta::Spec/version_ranges>) is available in C<%INC>. Does not load the module, so is safe to use with modules that have side effects when loaded.  When passed a second argument, returns true or false; otherwise, returns undef or the module's C<$VERSION>. (Current API available since version 0.015.)
+C<has_module($module [, $version_or_range ])> - checks if a module (optionally, at a specified version or matching a L<version range|CPAN::Meta::Spec/version_ranges>) is available in C<%INC>. Does not load the module, so is safe to use with modules that have side effects when loaded.  When passed a second argument, returns true or false; otherwise, returns undef or the module's C<$VERSION>. Note that for extremely simple usecases (module has no side effects when loading, and no explicit version is needed), it can be simpler and more backcompat-friendly to simply do: C<< eval { require Foo::Bar } >>. (Current API available since version 0.015.)
 
 =item *
 
